#!/usr/bin/python

#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License version 3 as
#published by the Free Software Foundation;

#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.

#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#Author: Marco Guastella alias Vasta
#Web page:<www.ragnu.it>
#Email: <vasta@ragnu.it>
#Date last Update : 04/04/2024

#use setup and pysetup  as explained in installer software
#import vmpbuild as build

import vmpconfig as config
import vmppybuild as pybuild

##Module name
name="clientjrp"

pysetup=pybuild.pysetup()
pysetup.dirmain="{0}{1}/".format(config.gmodules_,name)
pysetup.dependencies=['vmp','vmp_net','vmp_plugin','vmp_event','vmp_crypto','vmp_json','vmp_jrp']

def description():
    return "Module used for creating jrp clients,by running an 'client.jrp' plugin"
    
def install():
    pybuild.pybuild(pysetup)

def uninstall():
    pybuild.pyclear(pysetup)

